#
# spec file for package kio-extras5
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname kio-extras
%define kf5_version 5.60.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kio-extras5
Version:        20.04.2
Release:        bp153.3.3.1
Summary:        Additional KIO slaves for KDE applications
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM
Patch0:         0001-copy-FindTaglib-from-ECM.patch
BuildRequires:  OpenEXR-devel
BuildRequires:  flac-devel
BuildRequires:  gperf
BuildRequires:  kf5-filesystem
BuildRequires:  kdsoap-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmtp-devel
BuildRequires:  libssh-devel
BuildRequires:  libtag-devel
BuildRequires:  openslp-devel
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  cmake(KF5Activities)
BuildRequires:  cmake(KF5ActivitiesStats)
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DNSSD)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5KDELibs4Support)
BuildRequires:  cmake(KF5KHtml)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Pty)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(KF5SyntaxHighlighting)
BuildRequires:  cmake(Phonon4Qt5)
BuildRequires:  cmake(Qt5DBus) >= 5.4.0
BuildRequires:  cmake(Qt5Network) >= 5.4.0
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Svg) >= 5.4.0
BuildRequires:  cmake(Qt5Test) >= 5.4.0
BuildRequires:  cmake(Qt5Widgets) >= 5.4.0
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(smbclient)
Recommends:     %{name}-lang
Recommends:     kimageformats
# we want some imageformats in
Recommends:     libqt5-qtimageformats
Provides:       kfileaudiopreview = 4.100.0
Obsoletes:      kfileaudiopreview < 4.100.0
Provides:       kde-odf-thumbnail = %{version}
Obsoletes:      kde-odf-thumbnail < %{version}
%if %{with lang}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif

%description
Additional KIO-slaves for KDE applications.

%package -n libkioarchive5
Summary:        The archiver base class library
Group:          System/Libraries

%description -n libkioarchive5
The archiver base class, used by specific archive formats, is made
available as a library in its own right so that support for other
archive formats can be built outside the kio-extras source tree.

%package -n libkioarchive-devel
Summary:        Development package for libkioarchive5
Group:          Development/Libraries/C and C++
Requires:       libkioarchive5 = %{version}

%description -n libkioarchive-devel
This is the development package for libkioarchive

%if %{with lang}
%lang_package
%endif

%prep
%setup -q -n %{rname}-%{version}
%patch0 -p1
sed -i '/^add_subdirectory( doc )/d' CMakeLists.txt

%build
  %cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=share/locale/kf5
  %cmake_build

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %{kf5_find_lang}
    %{kf5_find_htmldocs}
  %endif
  # Unused D-Bus interface description
  rm %{buildroot}%{_kf5_sharedir}/dbus-1/interfaces/kf5_org.kde.network.kioslavenotifier.xml
  rmdir %{buildroot}%{_kf5_sharedir}/dbus-1/interfaces/

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post   -n libkioarchive5 -p /sbin/ldconfig
%postun -n libkioarchive5 -p /sbin/ldconfig

%files
%license COPYING.*
%{_kf5_configkcfgdir}/
%{_kf5_libdir}/libmolletnetwork5.so.*
%{_kf5_plugindir}/
%{_kf5_servicesdir}/
%{_kf5_servicetypesdir}/
%{_kf5_sharedir}/kio_bookmarks/
%{_kf5_sharedir}/kio_docfilter/
%{_kf5_sharedir}/kio_info/
%{_kf5_sharedir}/konqsidebartng/
%{_kf5_sharedir}/konqueror/
%{_kf5_sharedir}/mime/packages/kf5_network.xml
%{_kf5_sharedir}/remoteview/
%{_kf5_sharedir}/solid/
%{_kf5_sharedir}/dbus-1/services/org.kde.kmtp.daemon.service
%{_kf5_debugdir}/kio-extras.categories

%files -n libkioarchive-devel
%{_kf5_includedir}/kio_archivebase.h
%{_kf5_includedir}/libkioarchive_export.h
%{_libdir}/cmake/KioArchive/

%files -n libkioarchive5
%license COPYING.*
%{_libdir}/libkioarchive.so.5*

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Wed Aug 25 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Don't delete the DBus service file, it's got nothing to do with
  development (boo#1189687)
* Fri Feb 19 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patch from upstream to link correctly to taglib:
  * 0001-copy-FindTaglib-from-ECM.patch
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- Changes since 20.04.1:
  * Fix kio-extras compilation with -DQT_NO_CAST_TO_ASCII
  * smb: reshuffle discovery systems (kde#421624)
  * sftp: map sftp_open error to kio error
  * sftp: break large writes into multiple requests (kde#404890)
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Only store password in KWallet if the user asked for it
  * smb: resolve potential dnssd names via kdnssd
  * sftp: successfully write files to proftpd servers (kde#419999)
  * smb: put unmapped errno value into error message
  * smb: accurately attempt to resolve the correct WSD host (kde#420578)
- Dropped patches, now upstream:
  * smb-accurately-attempt-to-resolve-the-correct-WSD-host.patch
* Sun May  3 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add smb-accurately-attempt-to-resolve-the-correct-WSD-host.patch
  to fix some problems connecting to hosts found via the new
  WS-Discovery method (kde#420578)
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * sftp: extra verbosity when put fails
  * smb: debug the smbc debug level
  * Fix lifetime of slot in KIO-MTP
  * smb: add hack to support spaces in workgroup names (kde#204423)
  * smb: use prettyname.kio-discovery-wsd for hostname of wsdiscoveries
  * import license copies via reuse
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * sftp: fix partial transfer resuming when copying to local
  * sftp: do not show creation time when we do not know it (kde#375305)
  * smb: add some more topical debug output on opendir failure
  * add some extra debug in case stat fails
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * sftp: fix seekPos + file resuming when part file is of size 11 (kde#417645)
  * add readdirplus2 support for samba>=4.12 (kde#402988)
  * smb: fix ipv6 support (kde#417682)
  * add initial wsdiscovery support (kde#392447)
  * smb: map EHOSTUNREACH to ERR_CANNOT_CONNECT (kde#417166)
  * Improved quality of JPEG thumbnails (kde#411262)
  * Restore cursor thumbnailer (kde#387660)
  * fix preview of plain text files when using dark theme (kde#409380, kde#406821)
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Too many changes since 19.12.2, only listing bugfixes:
  * smb: enable anonymous and domain extra field in authinfo (kde#327484)
  * smb: disable mode bits getting forwarded to KIO (kde#414482)
  * smb: map ECONNABORTED to ERR_CONNECTION_BROKEN (kde#415436)
  * smb: install smb as both smb:// and cifs:// (kde#327295)
  * smb: do not map uid and gid (kde#212801)
  * smb: fix free space calculation (kde#298801)
  * smb: support more advanced hidden file flag (kde#307353)
  * smb: call smb_cutime on the correct url to actually set mtime properly (kde#356651)
  * smb: retain atime properly (kde#410624)
* Wed Feb 12 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add cmake(KF5ActivitiesStats) for the recentlyused:/ protocol
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- No code change since 19.12.0
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- No code change since 19.11.90
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * Apply KIO's klauncher CI workaround here too
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes since 19.08.3, only listing bugfixes:
  * [Comic Thumbnailer] Add support for 7zip-compressed comic books (kde#410696)
- Dropped patches, now upstream:
  * 0001-make-the-libssh-finder-ensure-the-new-ssh-target-is-.patch
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * fix password error condition handling of smb mount
  * improve error reporting for when kpasswdserver is unreachable
- Add upstream patch to support building with newer libssh:
  * 0001-make-the-libssh-finder-ensure-the-new-ssh-target-is-.patch
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Fixing implementation of FileJob interface in smb/sftp slaves
  * Fixing bug where MTP slave does not return error in stat()/mimetype()
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * [Text thumbnailer] Don't show text preview for .directory and .flatpakref files (kde#410561)
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * kio_sftp: QFile::rename takes QString, so remove erroneous QFile::encodeName
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * No code changes since 19.03.80
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Use more https with links
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * [Comic Thumbnailer] fix CBR thumbnail generation
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * [thumbnailer appimage] Fix building with libappimage not in system path
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
- Dropped patches, now upstream:
  * 0001-sftp-bump-pending-request-count-from-1-to-128.patch
- Dropped patches, superseded by upstream changes:
  * fix-mtp-paste-with-KF5-5.25.diff
- Provide / obsolete kde-odf-thumbnail. now kio-extras ships with
  its own ODF thumbnailer
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * apply eexist workaround from listDir to stat as well (kde#399699)
  * Avoid crash by not checking free space for smb://
- Dropped patches, now upstream:
  * 0001-Avoid-crash-by-not-checking-free-space-for-smb.patch
* Wed Oct 17 2018 Luca Beltrame <lbeltrame@kde.org>
- Add upstream patch 0001-Avoid-crash-by-not-checking-free-space-for-smb.patch
  * Prevents crashes when browsing smb://
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Wed Sep 19 2018 Luca Beltrame <lbeltrame@kde.org>
- Add upstream patch 0001-sftp-bump-pending-request-count-from-1-to-128.patch
  * Increase sftp file reading speed up to 20 times
* Fri Sep  7 2018 lbeltrame@kde.org
- Disable WebEngine BuildReq and add %%license
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Add license text of GPL 2.0, LGPL 2.0 and LGPL 2.1
  * Avoid a kio-mtp crash when trying to add a blocked device to the device cache
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Remove an space and a new line
  * fix sftp links with new uds implementation
  * Don't generate thumbnail for desktop files (kde#220330)
  * [activity plugin] Use the imperative mood to match all other Dolphin plugins
  * Rename KActivities linking plugin
  * Constrain libsmbclient bug workaround to affected versions only
  * Use a more intuitive, user-friendly name for Samba share access (kde#141257)
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * fix sftp links with new uds implementation
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * Scale up folder icon before creating preview overlays
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Workaround incorrectly returned EEXIST instead of EPERM regression introduced by libsmbclient 4.7 (kde#385708)
  * Use KIO::PreviewJob::defaultPlugins()
  * Use KIO::PreviewJob::defaultPlugins()
  * Don't enter test subdirectories if BUILD_TESTING=OFF
  * Set version in project()
  * kfileaudiopreview: don't autoplay media files by default
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Workaround incorrectly returned EEXIST instead of EPERM regression introduced by libsmbclient 4.7 (kde#385708)
  * Fix smb:/ handling
- Drop workaround-bug-in-libsmbclient-4.7.patch (merged upstream)
* Wed Nov  1 2017 wbauer@tmo.at
- Add workaround-bug-in-libsmbclient-4.7.patch to make browsing
  samba shares work with libsmbclient 4.7 (boo#1065868, kde#385708)
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Thu Aug 17 2017 jengelh@inai.de
- Fix incomplete sentence structure in description.
* Mon Aug 14 2017 fabian@ritter-vogt.de
- Only BuildRequire Qt WebEngine if available
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Allow write access to Samba Shares' root
* Sat Jul  8 2017 fabian@ritter-vogt.de
- Fix obsoletes
* Wed Jul  5 2017 jengelh@inai.de
- Fix grammar errors in description.
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Tue May 23 2017 wbauer@tmo.at
- Add "BuildRequires: gperf" to enable building the man kio-slave
  (boo#1040444)
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Add set_package_properties for Qt5WebEngineWidgets
  * Rename almost all the translation template (conflicts)
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 alarrosa@suse.com
- Rebase 0001-Add-an-AudioThumnail.patch
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Fix kio_sftp hanging when server doesn't support statvfs
  * kio_mtp: add write permissions to root storage folder
  * Fix install files
  * Enable html thumbnail
  * Thumbnails should be a clean image representation, remove frame.
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
- Added patches:
  + 0001-Add-an-AudioThumnail.patch
  + fix-mtp-paste-with-KF5-5.25.diff
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Thu Apr 21 2016 wbauer@tmo.at
- Conflict with kactivities5 5.19.0 and earlier to prevent file
  conflicts. The activities fileitem_linking_plugin and kio slave
  have been moved from kactivities5 to kio-extras5 in 16.04
  (boo#976592)
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Drop patches merged upstream:
  0001-Port-comicbook-thumbnailer-to-KF5.patch,
  0002-Port-textcreator-thumbnailer.patch,
  0003-don-t-screw-up-the-filenames.patch,
  0004-Added-support-for-NFSv3-major-refactoring-fixed-bugs.patch
  and 0005-kio_sftp-Use-the-right-type-for-timeout_sec-and-time.patch
- Add libmtp-devel BuildRequires
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * Fixed CVE-2014-8600
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
- Drop sanitize_path.patch, merged upstream
* Thu Nov 13 2014 hrvoje.senjan@gmail.com
- Added sanitize_path.patch from upstream, CVE-2014-8600
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
- Added patches from upstream:
  0001-Port-comicbook-thumbnailer-to-KF5.patch,
  0002-Port-textcreator-thumbnailer.patch (kde#339456),
  0003-don-t-screw-up-the-filenames.patch,
  0004-Added-support-for-NFSv3-major-refactoring-fixed-bugs.patch
  (kde#268797, kde#309113)
  0005-kio_sftp-Use-the-right-type-for-timeout_sec-and-time.patch
  (kde#331674)
- Added kpty-devel BuildRequires
* Sat Oct 25 2014 hrvoje.senjan@gmail.com
- Recommend lang subpackage
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Remove ktrash and kio_trash, merged in KIO framework since 5.3.0
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor changes to samba kio
- Install translations
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Fri Sep 12 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140912 (rc494702):
  * kio_trash: implement trash spec v1.0
  * Thumbnailer improvements
- Added pkgconfig(Qt5Svg) BuildRequires
* Fri Aug  8 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Translation updates
* Mon Jul 28 2014 hrvoje.senjan@gmail.com
- Add kimageformats and libqt5-qtimageformats recommends
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Tue Jun 10 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0
  * Beta 2 of Plasma 5 release
- Drop update_to_latest_head.patch
* Wed Jun  4 2014 hrvoje.senjan@gmail.com
- Add Source URL
- Added update_to_latest_head.patch, to sync with latest KF5 API
- Bump Qt requires to 5.3.0
- Added phonon4qt5-devel
- Obsolete and provide kfileaudiopreview, it is merged in kio-extras
* Sat May 17 2014 hrvoje.senjan@gmail.com
- Mark license as GPL-2.0+
* Sat May 10 2014 hrvoje.senjan@gmail.com
- Activate kio-extras5 package
